/**
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, version 2.1, dated February 1999.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the latest version of the GNU Lesser General
 * Public License as published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program (LICENSE.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.jamwiki.model;

/**
 * This is the failsafe Integrity settings. Basically it disallows any votes and
 * level changes until a proper Integrity Settings has been loaded.
 * This is loaded if there is an error in the configuration file to prevent down
 * time in the wiki.
 * @author poul
 */
public class IntegritySettingsFailsafe implements IntegritySettingsI {
	    /**
     * Gives a description of the integrity settings implemented.
     * @return the string that can be put on the homepage as clean text
     */
    public String getDescription() {
		return "Failsafe mode enabled";
	}

    /**
     * updates the logic. The actual logic is implementation dependent.
     */
    public void updateLogic() {

	}

    /**
     * Determens if a user is allowed to vote
     * @param wu The wikiuser that wants to vote
     * @param wv The vote the user wants to vote for
     * @return true if the user is allowed to vote.
     */
    public boolean userCanVote(WikiUser wu, WikiVote wv) {
		return false;
	}

    /**
     * Max level the topic may be moved up to by vote.
     * @param caller the user that wants to increase the level
     * @param id The topic that needs to get its level increased
     * @return the level it may be moved to.
     */
    public int maxLevelForTopic(WikiUser caller, Topic id) {
		return -1;
	}

	public int minLevelForTopic(WikiUser caller, Topic topic) {
		return -1;
	}

    /**
     * The max level the user may be moved to by a single vote.
     * @param user the user in question
     * @return the level that the user may be moved to by vote.
     */
    public int maxLevelForUser(WikiUser user) {
		return -1;
	}

	public int minLevelForUser(WikiUser user) {
		return -1;
	}

	/**
	 * Can the users votes affect the user in question:
	 * @param caller The user that wants to vote
	 * @param target The user that will be voted for
	 * @return If the vote will count
	 */
	public boolean userCanVote(WikiUser caller, WikiUser target) {
		return false;
	}

	public boolean userCanVoteDown(WikiUser caller, WikiUser target) {
		return false;
	}

	public void fillDates(WikiVote vote) {

	}

	/**
     * Checks a vote for ended expired etc.
     * @param v the vote to be handled
     */
    public void handleVote(WikiVote v) {
		
	}
}
