/**
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, version 2.1, dated February 1999.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the latest version of the GNU Lesser General
 * Public License as published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program (LICENSE.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.jamwiki.model;

import java.sql.Timestamp;
import java.util.*;

/**
 * This is a WikiVote structure. Not all of the properties needs to be set.
 */
public class WikiVote {
    private int voteId;
    //This is the user that the vote is about
	private WikiUser target;

	private WikiUser caller; //The user that initialized the vote
	private Timestamp start; //The date the vote was started (mandatory!)
    private Timestamp end; //The date the vote should end if there are enough votes
    private Timestamp expires; //The late date the vote should end
    private boolean active; //The vote is active
    private int level; //The level that we want to move the user to

	/**
	 * Constructor that uses a WikiUser as a target.
	 * @param voteId
	 * @param s Time the vote started
	 * @param target User that we vote about
	 * @param active The vote is still active
	 */
    public WikiVote(int voteId, Timestamp s, WikiUser target, boolean active) {
        this.voteId = voteId;
        this.start = s;
        end = null;
        expires = null;
		this.target = target;
        this.active = active;
    }

    public int getId() {
        return voteId;
    }

    /**
     * @return the end
     */
    public Timestamp getEnd() {
        return end;
    }

    /**
     * @param end the end to set
     */
    public void setEnd(Timestamp end) {
        this.end = end;
    }

    /**
     * @return the expires
     */
    public Timestamp getExpires() {
        return expires;
    }

    /**
     * @param expires the expires to set
     */
    public void setExpires(Timestamp expires) {
        this.expires = expires;
    }

    /**
     * @return the target
     */
    public WikiUser getTarget() {
        return target;
    }

    /**
     * @param target the target to set
     */
    public void setTarget(WikiUser target) {
        this.target = target;
    }

	/**
	 * Determens if a vote has expired
	 * @param ts Current time
	 * @return true if expired
	 */
    public boolean expired(Timestamp ts) {
        if(this.expires == null)
            return false;
        if(ts.after(this.expires))
            return true;
        return false;
    }

	/**
	 * Determens if a vote has formally ended
	 * @param ts Currnt time
	 * @return true if ended
	 */
    public boolean ended(Timestamp ts) {
        if(this.end == null)
            return false;
        if(ts.after(this.end))
            return true;
        return false;
    }

	/**
	 * Determens if a vote has formally ended
	 * @param ts Currnt time
	 * @return true if ended
	 */
    public boolean ended(Date ts) {
        if(this.end == null)
            return false;
        if(ts.after(this.end))
            return true;
        return false;
    }

    /**
     * @return the level
     */
    public int getLevel() {
        return level;
    }

    /**
     * @param level the level to set
     */
    public void setLevel(int level) {
        this.level = level;
    }

    /**
     * @return the active
     */
    public boolean isActive() {
        return active;
    }

    /**
     * @param active the active to set
     */
    public void setActive(boolean active) {
        this.active = active;
    }

	/**
	 * @return the start
	 */
	public Timestamp getStart() {
		return start;
	}

	/**
	 * @return the caller
	 */
	public WikiUser getCaller() {
		return caller;
	}

	/**
	 * @param caller the caller to set
	 */
	public void setCaller(WikiUser caller) {
		this.caller = caller;
	}

    
}
