/**
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, version 2.1, dated February 1999.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the latest version of the GNU Lesser General
 * Public License as published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program (LICENSE.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.jamwiki.servlets;

import java.util.HashMap;
import java.util.Map;
import java.util.Iterator;
import java.util.Random;
import java.util.Vector;
import org.jamwiki.model.Role;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jamwiki.WikiMessage;
import org.jamwiki.utils.WikiLogger;
import org.jamwiki.utils.WikiUtil;
import org.jamwiki.WikiBase;
import org.jamwiki.model.IntegritySettingsHandler;
import org.jamwiki.model.WikiUser;
import org.jamwiki.utils.LinkUtil;
import org.springframework.web.servlet.ModelAndView;

/**
 *
 * @author poul
 */
public class AllVotesServlet extends JAMWikiServlet {
	/** Logger for this class and subclasses. */
	private static final WikiLogger logger = WikiLogger.getLogger(SpecialPagesServlet.class.getName());
	/** The name of the JSP file used to render the servlet output. */
	protected static final String JSP_SPECIAL_PAGES = "all-votes.jsp";

	protected ModelAndView handleJAMWikiRequest(HttpServletRequest request, HttpServletResponse response, ModelAndView next, WikiPageInfo pageInfo) throws Exception {
		integrityPage(request, next, pageInfo);
		return next;
	}

	/**
	 * Handles everything
	 * @param request
	 * @param next
	 * @param pageInfo
	 * @throws java.lang.Exception
	 */
    private void integrityPage(HttpServletRequest request, ModelAndView next, WikiPageInfo pageInfo) throws Exception {
		//All Votes is a special page, that may not be edited.
		pageInfo.setContentJsp(JSP_SPECIAL_PAGES);
		pageInfo.setSpecial(true);
		pageInfo.setPageTitle(new WikiMessage("specialpages.caption.allvotes"));
		//get a map with all votes that are currently in progress
		Map m = WikiBase.getDataHandler().getActiveVotes();
		//if the user is logged in then we want a short list of 5 votes that he should vote on.
		Vector<String> selectionList = null; //List of html code
		WikiUser actualuser = null; //The user that views the page
		if(!ServletUtil.currentUserDetails().hasRole(Role.ROLE_ANONYMOUS)) {
			actualuser = ServletUtil.currentWikiUser(); //If the user is not anonymous then get the actual user
			selectionList = new Vector<String>(); //Init the string, there is a user so we need it
		}
		String s = new String(""); //Pure html that is being sent to the jsp file
		//Iterate through the set
		Iterator itr = m.keySet().iterator();
		//Occationally getting the virtual wiki will fail. Fallback to the english version if it happens
		String virtualWiki = WikiUtil.getVirtualWikiFromRequest(request);
		if(virtualWiki == null)
			virtualWiki = "en";
		//Now iterate through the votes in progress
		while(itr.hasNext()) {
			Integer key = (Integer)itr.next();
			Integer value = (Integer)m.get(key);
			WikiUser target = WikiBase.getDataHandler().lookupWikiUser(key);
			String username = target.getUsername();
			String classificationLink = "Special:UserClassification?contributor=" + username;
			//Create the destination address:
			String linkhtml = LinkUtil.buildTopicUrl(request.getContextPath(), virtualWiki, classificationLink, false);
			//If the logged in user can vote then also add it to the selected votes:
			if(actualuser!=null && IntegritySettingsHandler.getInstance().userCanVote(actualuser, target)) {
				selectionList.add("<a href=\""+linkhtml+"\"> "+ username + " --> "+value+"<a/><br/>");
			}
			//Add to the full list regardless
			s +=  "<a href=\""+linkhtml+"\"> "+ username + " --> "+value+"<a/><br/>";
		}
		//Add the object to jsp:
		next.addObject("content", s);
		if(selectionList!=null) { //If there is a list
			//Initialize the random generator
			Random r = new Random(ServletUtil.currentWikiUser().getUserId());
			while (selectionList.size()>5) {
				//Remove elements from the list until there is max 5 left.
				selectionList.remove(r.nextInt(selectionList.size()));
			}
			//Now generate the html:
			String s2 = new String();
			for(int i=0;i<selectionList.size();i++) {
				s2 += selectionList.elementAt(i);
			}
			//Send the html to jsp:
			next.addObject("selection", s2); //The html
			next.addObject("selection_availeble", "1"); //Show that the html has been generated
		} else {
			//Tell jsp that the user selection has not been generated
			next.addObject("selection_availeble", "0");
		}
		IntegritySettingsHandler.getInstance().runLogic();
	}
}
